#
# spec file for package ghc-filepath-bytestring
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name filepath-bytestring
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.2.1.13
Release:        2.2
Summary:        Library for manipulating RawFilePaths in a cross platform way
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
%endif

%description
This package provides functionality for manipulating 'RawFilePath' values.
It can be used as a drop in replacement for the filepath library to get the
benefits of using ByteStrings. It provides three modules:

* "System.FilePath.Posix.ByteString" manipulates POSIX/Linux style
'RawFilePath' values (with '/' as the path separator).

* "System.FilePath.Windows.ByteString" manipulates Windows style 'RawFilePath'
values (with either '\' or '/' as the path separator, and deals with drives).

* "System.FilePath.ByteString" is an alias for the module appropriate to your
platform.

All three modules provide the same API, and the same documentation (calling out
differences in the different variants).

This package is now deprecated, since filepath 1.4.100.0 provides an OsPath
type that is based on a bytestring. See
https://hasufell.github.io/posts/2022-06-29-fixing-haskell-filepaths.html.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cabal-tweak-dep-ver base "< 4.19" "< 5"

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG README.md TODO

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Mar 12 2024 Peter Simons <psimons@suse.com>
- Jailbreak build for ghc-9.8.x.
* Tue Jun 20 2023 Peter Simons <psimons@suse.com>
- Update filepath-bytestring to version 1.4.2.1.13.
  filepath-bytestring (1.4.2.1.13) unstable; urgency=medium
  * Relax bounds to allow base-4.18 and filepath-1.4.100.3 (ghc 9.6).
  - - Joey Hess <id@joeyh.name>  Tue, 20 Jun 2023 12:22:31 -0400
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Oct 22 2022 Peter Simons <psimons@suse.com>
- Update filepath-bytestring to version 1.4.2.1.12.
  filepath-bytestring (1.4.2.1.12) unstable; urgency=medium
  * Relax bounds to allow base 4.17 (ghc 9.4).
  - - Joey Hess <id@joeyh.name>  Thu, 20 Oct 2022 13:25:40 -0400
  filepath-bytestring (1.4.2.1.11) unstable; urgency=medium
  * Deprecated this library, since filepath has added OsPath that
    is based on a bytestring.
  - - Joey Hess <id@joeyh.name>  Sat, 23 Jul 2022 12:41:53 -0400
  filepath-bytestring (1.4.2.1.10) unstable; urgency=medium
  * Depend on bytestring-0.11.2.0, and use it to implement encodeFilePath
    and decodeFilePath, whose code was previously copied from it.
  - - Joey Hess <id@joeyh.name>  Wed, 08 Dec 2021 18:55:24 -0400
* Fri Dec  3 2021 Peter Simons <psimons@suse.com>
- Update filepath-bytestring to version 1.4.2.1.9.
  filepath-bytestring (1.4.2.1.9) unstable; urgency=medium
  * Relax bounds to allow base 4.16 (ghc 9.2).
  - - Joey Hess <id@joeyh.name>  Fri, 03 Dec 2021 11:49:58 -0400
* Thu Aug 12 2021 psimons@suse.com
- Update filepath-bytestring to version 1.4.2.1.8.
  filepath-bytestring (1.4.2.1.8) unstable; urgency=medium
  * Faster implementations of encodeFilePath and decodeFilePath.
    They are approximately 2x and 3x as fast, respectively.
  * encodeFilePath and decodeFilePath used to truncate at the first
    NUL. The new implementations do not do this. Since unix filepaths
    cannot contain NUL, this behavior change is can't cause any problems,
    unless the functions are used for values that are not actually
    valid filepaths.
  * Support cabal bench to benchmark the library.
  - - Joey Hess <id@joeyh.name>  Wed, 11 Aug 2021 12:17:15 -0400
* Thu Mar 18 2021 psimons@suse.com
- Update filepath-bytestring to version 1.4.2.1.7.
  filepath-bytestring (1.4.2.1.7) unstable; urgency=medium
  * Relax QuickCheck bounds to allow 2.14.
  * Relax base bounds so it will build with ghc 9.0.1.
  - - Joey Hess <id@joeyh.name>  Wed, 17 Mar 2021 08:11:27 -0400
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add filepath-bytestring at version 1.4.2.1.6.
